# [Jspaste](https://jspaste.tnfangel.repl.co)[.py](https://github.com/pruebando/jspaste/blob/master/README.md)

- [Español](#español)

- [English](#english)

## English


## Español

1. [Instalación](#instalacion)
2. Funciones




## **Instalacion**

Para instalar el paquete puedes directamente instalarlo desde GitHub 
> pip install https://github.com/pruebando/jspaste/

O proximamente

> pip install jspaste
**actualmente no funciona, en un futuro a lo mejor**

## **



